@@ -1,3 +1,4 @@
+from logging import DEBUG, INFO, CRITICAL, WARNING, FATAL
 from .localshell import LocalShell
 from .secureshell import SecureShell
 from .shellerror import ShellError
@@ -8,5 +9,7 @@ from .serialshell import SerialShell
 from .shell import Shell
 from .parseduri import ParsedUri
 
+__version__="2.3.1"
+
 sh = Shell()
 
